==> react-molecule-tabs-2.32.0.tgz: package/lib/components/MoleculeTab.js <==
import { useEffect, useRef, forwardRef } from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
import useMergeRefs from '@s-ui/react-hooks/lib/useMergeRefs';
import { CLASS_TAB, CLASS_TAB_ICON, CLASS_TAB_COUNT, CLASS_TAB_ACTIVE, CLASS_TAB_DISABLED } from './config.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var MoleculeTab = /*#__PURE__*/forwardRef(function (_ref, forwardedRef) {
  var _cx;

  var active = _ref.active,
      onChange = _ref.onChange,
      disabled = _ref.disabled,
      icon = _ref.icon,
      count = _ref.count,
      label = _ref.label,
      numTab = _ref.numTab,
      isIntersecting = _ref.isIntersecting;
  var innerRef = useRef();

  var handleChange = function handleChange(ev) {
    !disabled && onChange(ev, {
      numTab: numTab
    });
  };

  useEffect(function () {
    if (active && isIntersecting) {
      innerRef.current.scrollIntoView({
        behavior: 'smooth',
        block: 'nearest',
        inline: 'start'
      });
    }
  }, [active, isIntersecting, innerRef]);
  var className = cx(CLASS_TAB, (_cx = {}, _cx[CLASS_TAB_ACTIVE] = active, _cx[CLASS_TAB_DISABLED] = disabled, _cx));
  return /*#__PURE__*/_jsxs("li", {
    className: className,
    onClick: handleChange,
    ref: useMergeRefs(innerRef, forwardedRef),
    children: [icon && /*#__PURE__*/_jsx("span", {
      className: CLASS_TAB_ICON,
      children: icon
    }), !isNaN(count) && /*#__PURE__*/_jsx("span", {
      className: CLASS_TAB_COUNT,
      children: count
    }), /*#__PURE__*/_jsx("span", {
      children: label
    })]
  });
});
export default MoleculeTab;

==> react-molecule-tabs-2.36.0.tgz: package/lib/components/MoleculeTab.js <==
import { forwardRef, useEffect, useRef } from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
import useMergeRefs from '@s-ui/react-hooks/lib/useMergeRefs';
import { CLASS_TAB, CLASS_TAB_ACTIVE, CLASS_TAB_COUNT, CLASS_TAB_DISABLED, CLASS_TAB_ICON } from './config.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var MoleculeTab = /*#__PURE__*/forwardRef(function (_ref, forwardedRef) {
  var _cx;

  var active = _ref.active,
      _ref$autoScrollIntoVi = _ref.autoScrollIntoView,
      autoScrollIntoView = _ref$autoScrollIntoVi === void 0 ? true : _ref$autoScrollIntoVi,
      count = _ref.count,
      disabled = _ref.disabled,
      icon = _ref.icon,
      isIntersecting = _ref.isIntersecting,
      label = _ref.label,
      numTab = _ref.numTab,
      onChange = _ref.onChange;
  var innerRef = useRef();

  var handleChange = function handleChange(ev) {
    !disabled && onChange(ev, {
      numTab: numTab
    });
  };

  useEffect(function () {
    if (autoScrollIntoView && active && isIntersecting) {
      innerRef.current.scrollIntoView({
        behavior: 'smooth',
        block: 'nearest',
        inline: 'start'
      });
    }
  }, [autoScrollIntoView, active, isIntersecting, innerRef]);
  var className = cx(CLASS_TAB, (_cx = {}, _cx[CLASS_TAB_ACTIVE] = active, _cx[CLASS_TAB_DISABLED] = disabled, _cx));
  return /*#__PURE__*/_jsxs("li", {
    className: className,
    onClick: handleChange,
    ref: useMergeRefs(innerRef, forwardedRef),
    children: [icon && /*#__PURE__*/_jsx("span", {
      className: CLASS_TAB_ICON,
      children: icon
    }), !isNaN(count) && /*#__PURE__*/_jsx("span", {
      className: CLASS_TAB_COUNT,
      children: count
    }), /*#__PURE__*/_jsx("span", {
      children: label
    })]
  });
});
export default MoleculeTab;
